![](https://example.com/bucket/test.jpg)
![alt text](./image/test.jpg "title")
!\[test\](https://example.com/bucket/test%20space.jpg)
![test](https://example.com/bucket/test%23hash.jpg)
<img src="https://example.com/bucket/test.jpg" alt="html tag">
